@@ -1,7 +1,7 @@
 /* GENIUS Calculator
- * Copyright (C) 1997-2003 George Lebl
+ * Copyright (C) 1997-2004 Jiri (George) Lebl
  *
- * Author: George Lebl
+ * Author: Jiri (George) Lebl
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -25,8 +25,6 @@
 
 #include "config.h"
 
-#include <gnome.h>
-
 #include <glib.h>
 
 #include <string.h>
@@ -58,6 +56,8 @@
 
 #include "plugin.h"
 
+#include "genius-i18n.h"
+
 #include <readline/readline.h>
 #include <readline/history.h>
 
@@ -91,11 +91,11 @@ puterror(const char *s)
 	int line;
 	gel_get_file_info(&file,&line);
 	if(file)
-		fprintf(stderr,"%s:%d: %s\n",file,line,s);
+		g_printerr ("%s:%d: %s\n",file,line,s);
 	else if(line>0)
-		fprintf(stderr,_("line %d: %s\n"),line,s);
+		g_printerr (_("line %d: %s\n"),line,s);
 	else
-		fprintf(stderr,"%s\n",s);
+		g_printerr ("%s\n",s);
 }
 
 static void
@@ -111,7 +111,7 @@ void
 gel_printout_infos (void)
 {
 	if(errors_printed-curstate.max_errors > 0)
-		fprintf(stderr,_("Too many errors! (%d followed)\n"),
+		g_printerr (_("Too many errors! (%d followed)\n"),
 			errors_printed-curstate.max_errors);
 	errors_printed = 0;
 }
@@ -157,12 +157,12 @@ set_state(calcstate_t state)
 }
 
 static void
-interrupt(int sig)
+interrupt (int sig)
 {
 	interrupted = TRUE;
-	if(use_readline)
-		rl_stuff_char('\n');
-	signal(SIGINT,interrupt);
+	if (use_readline)
+		rl_stuff_char ('\n');
+	signal (SIGINT, interrupt);
 }
 
 static int
@@ -189,19 +189,23 @@ main(int argc, char *argv[])
 {
 	int i;
 	int inter;
-	int lastarg = FALSE;
+	gboolean lastarg = FALSE;
 	GSList *files = NULL;
 	char *file;
 	FILE *fp;
-	int do_compile = FALSE;
-	int be_quiet = FALSE;
+	gboolean do_compile = FALSE;
+	gboolean be_quiet = FALSE;
 
 	genius_is_gui = FALSE;
 
-	bindtextdomain(GETTEXT_PACKAGE,GNOMELOCALEDIR);
-	textdomain(GETTEXT_PACKAGE);
+	/* Hmmm, everything in UTF-8? */
+	bindtextdomain (GETTEXT_PACKAGE, GNOMELOCALEDIR);
+	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
+	textdomain (GETTEXT_PACKAGE);
 
-	signal(SIGINT,interrupt);
+	setlocale (LC_ALL, "");
+
+	signal (SIGINT, interrupt);
 
 	statechange_hook = set_state;
 
@@ -249,24 +253,24 @@ main(int argc, char *argv[])
 			be_quiet = FALSE;
 		else {
 			if(strcmp(argv[i],"--help")!=0) {
-				fprintf(stderr,"Unknown argument '%s'!\n\n",
+				g_printerr ("Unknown argument '%s'!\n\n",
 					argv[i]);
 			}
-			printf(_("Genius %s usage:\n\n"
-			       "genius [options] [files]\n\n"
-			       "\t--precision=num   \tFloating point precision [256]\n"
-			       "\t--maxdigits=num   \tMaximum digits to display (0=no limit) [0]\n"
-			       "\t--[no]floatresult \tAll results as floats [OFF]\n"
-			       "\t--[no]scinot      \tResults in scientific notation [OFF]\n"
-			       "\t--[no]fullexp     \tAlways print full expressions [OFF]\n"
-			       "\t--maxerrors=num   \tMaximum errors to display (0=no limit) [5]\n"
-			       "\t--[no]mixed       \tPrint fractions in mixed format\n"
-			       "\t--intoutbase=num  \tBase to use to print out integers [10]\n"
-			       "\t--[no]readline    \tUse readline if it is available [ON]\n"
-			       "\t--[no]compile     \tCompile everything and dump it to stdout [OFF]\n"
-			       "\t--[no]quiet       \tBe quiet during non-interactive mode,\n"
-			       "\t                  \t(always on when compiling) [OFF]\n\n"),
-			      VERSION);
+			g_print (_("Genius %s usage:\n\n"
+				   "genius [options] [files]\n\n"
+				   "\t--precision=num   \tFloating point precision [256]\n"
+				   "\t--maxdigits=num   \tMaximum digits to display (0=no limit) [0]\n"
+				   "\t--[no]floatresult \tAll results as floats [OFF]\n"
+				   "\t--[no]scinot      \tResults in scientific notation [OFF]\n"
+				   "\t--[no]fullexp     \tAlways print full expressions [OFF]\n"
+				   "\t--maxerrors=num   \tMaximum errors to display (0=no limit) [5]\n"
+				   "\t--[no]mixed       \tPrint fractions in mixed format\n"
+				   "\t--intoutbase=num  \tBase to use to print out integers [10]\n"
+				   "\t--[no]readline    \tUse readline if it is available [ON]\n"
+				   "\t--[no]compile     \tCompile everything and dump it to stdout [OFF]\n"
+				   "\t--[no]quiet       \tBe quiet during non-interactive mode,\n"
+				   "\t                  \t(always on when compiling) [OFF]\n\n"),
+				 VERSION);
 			exit(1);
 		}
 	}
@@ -292,15 +296,15 @@ main(int argc, char *argv[])
 		be_quiet = TRUE;
 	inter = isatty(0) && !files && !do_compile;
 	/*interactive mode, print welcome message*/
-	if(inter) {
-		printf(_("Genius %s\n"
-			 "%s\n"
-			 "This is free software with ABSOLUTELY NO WARRANTY.\n"
-			 "For license details type `warranty'.\n"
-			 "For help type 'manual' or 'help'.%s\n\n"),
-		       VERSION,
-		       COPYRIGHT_STRING,
-		       get_version_details ());
+	if (inter) {
+		g_print (_("Genius %s\n"
+			   "%s\n"
+			   "This is free software with ABSOLUTELY NO WARRANTY.\n"
+			   "For license details type `warranty'.\n"
+			   "For help type 'manual' or 'help'.%s\n\n"),
+			 VERSION,
+			 COPYRIGHT_STRING,
+			 get_version_details ());
 		be_quiet = FALSE;
 	}
 
@@ -322,7 +326,7 @@ main(int argc, char *argv[])
 	  dictionary*/
 	d_singlecontext ();
 
-	if(!do_compile) {
+	if ( ! do_compile) {
 		/*
 		 * Read main library
 		 */
@@ -433,7 +437,7 @@ main(int argc, char *argv[])
 				}
 			} while(!fp && files);
 			if(!fp && !files) {
-				if(do_compile) {
+				if (do_compile) {
 					gel_push_file_info(NULL,0);
 					gel_compile_all_user_funcs(stdout);
 					gel_pop_file_info();
