@@ -21,14 +21,12 @@
 
 #include "config.h"
 
-#include <gnome.h>
-
 #include <stdio.h>
 #include <string.h>
 #include <glib.h>
+#include "calc.h"
 #include "mpwrap.h"
 #include "eval.h"
-#include "calc.h"
 #include "dict.h"
 #include "util.h"
 #include "funclib.h"
@@ -484,7 +482,7 @@ gel_value_matrix_det (GelCtx *ctx, mpw_t rop, GelMatrixW *m)
 	g_assert (ctx->modulo == NULL);
 
 	if(w != h) {
-		(*errorout)(_("Determinant of a non-square matrix is undefined"));
+		gel_errorout (_("Determinant of a non-square matrix is undefined"));
 		return FALSE;
 	}
 	switch(w) {
